@@ -49,7 +49,6 @@ extern int getusers(struct channel *);
 extern int updateadmints(void);
 extern int updateuserts(struct channel *);
 extern int initenv(void);
-extern int allhostsknown(struct channel *);
 extern int burstjoins(struct channel *);
 extern int isq(char *);
 extern int isservice(char *);
@@ -101,7 +100,6 @@ extern int delchannel(struct channel *);
 extern int deladverts(struct channel *, char *);
 extern int getondiskmsgcount(struct channel *, char *);
 extern int getondiskjoincount(struct channel *, char *);
-extern int getrandom(int);
 extern int getrandommsg(struct channel *, char *, int, char *, int, int);
 extern int getjoincount(struct channel *, char *);
 extern int delserver(char *, int, int, int, int, int);
@@ -112,6 +110,7 @@ extern int timed_cmp(struct timed *, struct timed *);
 extern int isfriend(struct channel *, char *, char *);
 extern int deltachanflags(struct channel *, char *, char);
 extern int isvalidchannel(char *);
+extern unsigned int getrandom(unsigned int);
 extern struct authed *addnewauthed(struct channel *, time_t, struct botuser *, char *);
 extern struct botuser *addbotuser(char *, char *);
 extern struct botuser *addnewadmin(char *, char *);
@@ -180,7 +179,7 @@ extern void syncvoices(struct channel *);
 extern void syncops(struct channel *);
 extern void syncpermbans(struct channel *);
 extern void syncnickbks(struct channel *);
-extern void syncuserhosts(struct channel *);
+extern void syncuserhosts(void);
 extern void processenv(void);
 extern void processlock(struct channel *);
 extern void processnetjoin(struct channel *);
