@@ -254,6 +254,8 @@ enum OER_TIMED_PRIORITIES {
 #define OER_MAINLOOP_TIMEOUT_USECS 0
 /* only change this if you are 100% sure what you are doing */
 #define OER_ACTIONS_PER_MAINLOOP 2
+#define OER_KICKS_PER_MAINLOOP 1
+#define OER_KICK_INTERVAL 2
 #define OER_NICKS_PER_USERHOST 5
 /* multiple kicks aren't supported for backwards compatibility */
 #define OER_NICKS_PER_KICK 1
@@ -333,7 +335,7 @@ enum OER_TIMED_PRIORITIES {
 #define DBSTATUS_MSG "At least one of the executed database queries failed, more \
 details possibly available on the oer+MySQL console"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
-#define OER_COPYRIGHT1 "oer+MySQL version 1.0-22, Copyright (C) 2000-2001 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer+MySQL version 1.0-23, Copyright (C) 2000-2001 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer+MySQL comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
@@ -369,6 +371,7 @@ struct locked {
 	int locked;
 	int unlocked;
 	int auto_unlock;
+	time_t lastkick;
 	char reason[STRINGLEN + 1];
 	char nick[NICKLEN + 1];
 	char host[USERHOSTLEN + 1];
@@ -497,6 +500,7 @@ struct channel {
 	int topic_reset;
 	int synced;
         int bantype;
+	int allhostsknown;
 	time_t rejoin_at;
 	time_t last_quote;
 	time_t userts;
