@@ -215,69 +215,21 @@ int main(int argc, char *argv[])
 	}
 	/* from now on we write to console and/or database */
 	do_tempoutput = 0;
+	establishconnection();
+	if(mystate->bailout) {
+                exit(EXIT_FAILURE);
+        }
 	mystate->loopforever = 1;
 	while(mystate->loopforever) {
 #ifdef DEBUG
-        oer_debug(OER_DEBUG_FLOOD, "main->mainloop\n");
+		oer_debug(OER_DEBUG_FLOOD, "main->mainloop\n");
 #endif
-		mystate->now = time(NULL);
-		switch(serverconnection()) {
-		case OER_SERVERCONNECTION_ERR_SOCKET:
-#ifdef DEBUG
-			oer_debug(OER_DEBUG_FATAL, "main->socket() failed, exiting.\n");
-#endif
-			exit(EXIT_FAILURE);
-		case OER_SERVERCONNECTION_ERR_GETHOSTNAME:
-#ifdef DEBUG
-			oer_debug(OER_DEBUG_FATAL, "main->gethostname() failed, exiting.\n");
-#endif
-			exit(EXIT_FAILURE);
-		case OER_SERVERCONNECTION_ERR_GETHOSTBYNAME_RETRY:
-#ifdef DEBUG
-			oer_debug(OER_DEBUG_ERROR, "main->gethostbyname() temporary error, retrying.\n");
-#endif
-			sleep(OER_WAIT_BETWEEN_CONNECTION_ATTEMPTS);
-			break;
-		case OER_SERVERCONNECTION_ERR_GETSERVER_RETRY:
-#ifdef DEBUG
-			oer_debug(OER_DEBUG_ERROR, "main->getserver() temporary error, retrying.\n");
-#endif
-			sleep(OER_WAIT_BETWEEN_CONNECTION_ATTEMPTS);
-			break;
-		case OER_SERVERCONNECTION_ERR_GETHOSTBYNAME:
-#ifdef DEBUG
-			oer_debug(OER_DEBUG_FATAL, "main->gethostbyname() fatal error, exiting.\n");
-#endif
-			exit(EXIT_FAILURE);
-		case OER_SERVERCONNECTION_ERR_BIND:
-#ifdef DEBUG
-			oer_debug(OER_DEBUG_FATAL, "main->bind() fatal error, exiting.\n");
-#endif
-			exit(EXIT_FAILURE);
-		case OER_SERVERCONNECTION_ERR_CONNECT_RETRY:
-#ifdef DEBUG
-			oer_debug(OER_DEBUG_ERROR, "main->connect() temporary error, retrying.\n");
-#endif
-			sleep(OER_WAIT_BETWEEN_CONNECTION_ATTEMPTS);
-			break;
-		case OER_SERVERCONNECTION_ERR_CONNECT:
-#ifdef DEBUG
-			oer_debug(OER_DEBUG_FATAL, "main->connect() fatal error, exiting.\n");
-#endif
-			exit(EXIT_FAILURE);
-		case OER_SERVERCONNECTION_ALREADY_CONNECTED:
-		case OER_SERVERCONNECTION_EVERYTHING_OK:
-			break;
-		}
-		/* check if we are connected */
-		if((mystate->current_server == NULL) || !mystate->current_server->connected) {
-			continue;
-		}
 		FD_ZERO(&rsock);
 		FD_SET(mystate->sockfd, &rsock);
 		tv.tv_sec = OER_MAINLOOP_TIMEOUT_SECS;
 		tv.tv_usec = OER_MAINLOOP_TIMEOUT_USECS;
 		retval = select(mystate->sockfd + 1, &rsock, NULL, NULL, &tv);
+                mystate->now = time(NULL);
 		if(retval < 0) {
 #ifdef DEBUG
 			oer_debug(OER_DEBUG_ERROR, "main->select() failed: %s\n", strerror(errno));
@@ -300,7 +252,6 @@ int main(int argc, char *argv[])
 					break;
 				}
 			}
-			continue;
 		}
 		reconnect();
 		/* retval == 0, timeout */
@@ -319,9 +270,9 @@ int main(int argc, char *argv[])
 		/* do some housekeeping */
 		processenv();	
 		/* check if it's safe to do some server actions */
-		if((mystate->last_actions + 1) >= mystate->now) {
-			continue;
-		}
+                if(mystate->now <= mystate->last_actions) {
+                        continue;
+                }
 		switch(processtimeds()) {
 		case OER_PROCESSTIMEDS_ERR_WRITE:
 			mystate->reconnect = OER_RECONNECT_ERROR;
