@@ -1031,6 +1031,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
         int prevppos;
 	time_t uptime_seconds;
 	time_t idle_seconds;
+        time_t idle_per;
         char p1[STRINGLEN + 1];
         char p2[STRINGLEN + 1];
 	char outstring[WRITE_BUFFER_LENGTH + 1];
@@ -1317,13 +1318,14 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		}
 		/* allow admins to lock even if not "l" chanflag */
 		if(!isadmin(this, userhost)) {
-			if(haschanflags(this, "l")) {
-				if(haschanflags(this, "U") && !isatleastop(this, nick, userhost)) {
-					return;
-				}
-				if(!isatleastopnow(this, nick, userhost)) {
-					return;
-				}
+			if(!haschanflags(this, "l")) {
+				return;
+			}
+			if(haschanflags(this, "U") && !isatleastop(this, nick, userhost)) {
+				return;
+			}
+			if(!isatleastopnow(this, nick, userhost)) {
+				return;
 			}
 		}
                 lockchan(this, restptr, (which == OER_WHICHCOMMAND_LOCK) ? 0 : 1, nick, userhost);
@@ -1962,8 +1964,13 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		snprintf(outstring, WRITE_BUFFER_LENGTH, "oer+MySQL uptime: %s", uptimestring);
 		if(uptime(&uptime_seconds, &idle_seconds)) {
 			secondstostring(uptime_seconds, uptimestring, STRINGLEN);
+			idle_per = idle_seconds % uptime_seconds;
+                        idle_per = uptime_seconds - idle_per;
+                        idle_per *= 100;
+                        idle_per /= uptime_seconds;
+                        idle_per = 100 - idle_per;
 #ifdef OER_UPTIME_SHOW_IDLE
-			snprintf(outstring2, WRITE_BUFFER_LENGTH, ", host uptime: %s (idle %.2f%%)", uptimestring, ((float)((float)idle_seconds/(float)uptime_seconds) * 100.0));
+			snprintf(outstring2, WRITE_BUFFER_LENGTH, ", host uptime: %s (host idle: %lu%%)", uptimestring, idle_per);
 #else
 			snprintf(outstring2, WRITE_BUFFER_LENGTH, ", host uptime: %s", uptimestring);
 #endif
